# -*- coding: utf-8 -*-
"""
app.admin.validators
~~~~~~~~~~~~~~~~~~~~

This module defines field validators

:copyright: (c) 2017 European Spallation Source ERIC
:license: BSD 2-Clause, see LICENSE for more details.

"""
import ipaddress
from wtforms import ValidationError


class IPNetwork:
    """
    Validates an IP network.

    :param message:
        Error message to raise in case of a validation error.
    """
    def __init__(self, message=None):
        self.message = message

    def __call__(self, form, field):
        try:
            ipaddress.ip_network(field.data, strict=True)
        except (ipaddress.AddressValueError, ipaddress.NetmaskValueError, ValueError):
            if self.message is None:
                self.message = field.gettext('Invalid IP network.')
            raise ValidationError(self.message)
